# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fms.proto',
  package='fitelio.ms',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tfms.proto\x12\nfitelio.ms\"\x95\x02\n\x07Message\x12&\n\x06method\x18\x01 \x01(\x0e\x32\x16.fitelio.ms.SendMethod\x12&\n\x08provider\x18\x02 \x01(\x0e\x32\x14.fitelio.ms.Provider\x12\x12\n\nrecipients\x18\x05 \x03(\t\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x0b\n\x03uid\x18\x08 \x01(\t\x12\x0b\n\x03tag\x18\t \x01(\t\x12\x12\n\nalpha_name\x18\x0b \x01(\t\x12\r\n\x05topic\x18\x0c \x01(\t\x12\r\n\x05title\x18\r \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x0e \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x0f \x01(\t\x12\r\n\x05image\x18\x10 \x01(\t\x12\x12\n\nstart_time\x18\x15 \x01(\t\x12\x0b\n\x03ttl\x18\x16 \x01(\x05\"6\n\x0eMessageRequest\x12$\n\x07message\x18\x01 \x01(\x0b\x32\x13.fitelio.ms.Message\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\"G\n\x0fMessageResponse\x12 \n\x05\x65rror\x18\x01 \x01(\x0b\x32\x11.fitelio.ms.Error\x12\x12\n\nmessage_id\x18\x02 \x01(\t**\n\nSendMethod\x12\x08\n\x04push\x10\x00\x12\x07\n\x03sms\x10\x01\x12\t\n\x05viber\x10\x02*A\n\x08Provider\x12\x07\n\x03\x66\x63m\x10\x00\x12\x08\n\x04\x61pns\x10\x01\x12\x0c\n\x08turbosms\x10\x02\x12\n\n\x06twilio\x10\x03\x12\x08\n\x04gmsu\x10\x04\x32X\n\x13MessagingServiceAPI\x12\x41\n\x04Send\x12\x1a.fitelio.ms.MessageRequest\x1a\x1b.fitelio.ms.MessageResponse\"\x00\x62\x06proto3'
)

_SENDMETHOD = _descriptor.EnumDescriptor(
  name='SendMethod',
  full_name='fitelio.ms.SendMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='push', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='sms', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='viber', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=474,
  serialized_end=516,
)
_sym_db.RegisterEnumDescriptor(_SENDMETHOD)

SendMethod = enum_type_wrapper.EnumTypeWrapper(_SENDMETHOD)
_PROVIDER = _descriptor.EnumDescriptor(
  name='Provider',
  full_name='fitelio.ms.Provider',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='fcm', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='apns', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='turbosms', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='twilio', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='gmsu', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=518,
  serialized_end=583,
)
_sym_db.RegisterEnumDescriptor(_PROVIDER)

Provider = enum_type_wrapper.EnumTypeWrapper(_PROVIDER)
push = 0
sms = 1
viber = 2
fcm = 0
apns = 1
turbosms = 2
twilio = 3
gmsu = 4



_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='fitelio.ms.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='fitelio.ms.Message.method', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='fitelio.ms.Message.provider', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipients', full_name='fitelio.ms.Message.recipients', index=2,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='fitelio.ms.Message.text', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='fitelio.ms.Message.uid', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='fitelio.ms.Message.tag', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alpha_name', full_name='fitelio.ms.Message.alpha_name', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='fitelio.ms.Message.topic', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='fitelio.ms.Message.title', index=8,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='fitelio.ms.Message.data', index=9,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='fitelio.ms.Message.action', index=10,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='fitelio.ms.Message.image', index=11,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='fitelio.ms.Message.start_time', index=12,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='fitelio.ms.Message.ttl', index=13,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=303,
)


_MESSAGEREQUEST = _descriptor.Descriptor(
  name='MessageRequest',
  full_name='fitelio.ms.MessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='fitelio.ms.MessageRequest.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=359,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='fitelio.ms.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='fitelio.ms.Error.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='fitelio.ms.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=399,
)


_MESSAGERESPONSE = _descriptor.Descriptor(
  name='MessageResponse',
  full_name='fitelio.ms.MessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='fitelio.ms.MessageResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='fitelio.ms.MessageResponse.message_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=472,
)

_MESSAGE.fields_by_name['method'].enum_type = _SENDMETHOD
_MESSAGE.fields_by_name['provider'].enum_type = _PROVIDER
_MESSAGEREQUEST.fields_by_name['message'].message_type = _MESSAGE
_MESSAGERESPONSE.fields_by_name['error'].message_type = _ERROR
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['MessageRequest'] = _MESSAGEREQUEST
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['MessageResponse'] = _MESSAGERESPONSE
DESCRIPTOR.enum_types_by_name['SendMethod'] = _SENDMETHOD
DESCRIPTOR.enum_types_by_name['Provider'] = _PROVIDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'fms_pb2'
  # @@protoc_insertion_point(class_scope:fitelio.ms.Message)
  })
_sym_db.RegisterMessage(Message)

MessageRequest = _reflection.GeneratedProtocolMessageType('MessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREQUEST,
  '__module__' : 'fms_pb2'
  # @@protoc_insertion_point(class_scope:fitelio.ms.MessageRequest)
  })
_sym_db.RegisterMessage(MessageRequest)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'fms_pb2'
  # @@protoc_insertion_point(class_scope:fitelio.ms.Error)
  })
_sym_db.RegisterMessage(Error)

MessageResponse = _reflection.GeneratedProtocolMessageType('MessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERESPONSE,
  '__module__' : 'fms_pb2'
  # @@protoc_insertion_point(class_scope:fitelio.ms.MessageResponse)
  })
_sym_db.RegisterMessage(MessageResponse)



_MESSAGINGSERVICEAPI = _descriptor.ServiceDescriptor(
  name='MessagingServiceAPI',
  full_name='fitelio.ms.MessagingServiceAPI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=585,
  serialized_end=673,
  methods=[
  _descriptor.MethodDescriptor(
    name='Send',
    full_name='fitelio.ms.MessagingServiceAPI.Send',
    index=0,
    containing_service=None,
    input_type=_MESSAGEREQUEST,
    output_type=_MESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MESSAGINGSERVICEAPI)

DESCRIPTOR.services_by_name['MessagingServiceAPI'] = _MESSAGINGSERVICEAPI

# @@protoc_insertion_point(module_scope)



import datetime


def log_level_as_severity(logger, name: str, event_dict: dict) -> dict:
    """
    Adds logging level to `event_dict` as `severity` field
    """
    event_dict["severity"] = event_dict.pop("level", "info")
    return event_dict


def log_event_as_message(logger, name: str, event_dict: dict) -> dict:
    """
    Renames `event` field to `message`
    """
    event = event_dict.pop("event", None)
    if event:
        event_dict["message"] = event
    return event_dict


def log_timestamp_rfc3339(logger, name: str, event_dict: dict) -> dict:
    """
    Add timestamp into `event_dict` in RFC3339
    """
    event_dict["timestamp"] = datetime.datetime.utcnow().isoformat("T") + "Z"
    return event_dict



import logging.config
import os

import structlog
from fms.utils import log_event_as_message, log_level_as_severity, log_timestamp_rfc3339
from structlog import processors
from structlog.contextvars import merge_contextvars
from structlog.stdlib import BoundLogger, LoggerFactory

MS_SERVER_URL = os.environ.get("MS_SERVER_URL", "0.0.0.0:50000")

LOGGING = {
    "version": 1,
    "disable_existing_loggers": True,
    "formatters": {
        "default": {"format": "[%(asctime)s] [%(levelname)8s]: %(message)s"},
        "simple": {"format": "%(message)s"},
    },
    "handlers": {
        "console": {"class": "logging.StreamHandler", "formatter": "default", "level": "DEBUG"},
        "simple": {"class": "logging.StreamHandler", "formatter": "simple", "level": "DEBUG"},
    },
    "loggers": {"client": {"propagate": False, "handlers": ["simple"], "level": "DEBUG"},},
}
logging.config.dictConfig(LOGGING)

renderer_kv = processors.KeyValueRenderer(key_order=["timestamp", "severity", "message"], drop_missing=True)
renderer_json = processors.JSONRenderer()
logging_renderer = {"kv": renderer_kv, "json": renderer_json}.get(
    os.environ.get("LOGGING_RENDERER", "json"), renderer_json
)


structlog.configure(
    processors=[
        merge_contextvars,
        structlog.processors.StackInfoRenderer(),
        structlog.dev.set_exc_info,
        structlog.processors.format_exc_info,
        structlog.processors.TimeStamper(),
        structlog.stdlib.PositionalArgumentsFormatter(),
        log_timestamp_rfc3339,
        log_event_as_message,
        log_level_as_severity,
        logging_renderer,
    ],
    wrapper_class=BoundLogger,
    context_class=dict,
    logger_factory=LoggerFactory(),
    cache_logger_on_first_use=True,
)
